# ozobot-web
This codebase defines a web-based robot driver for controlling Ozobot robots **via Pyodide** (web based Python) to TypeScript API.

The driver implements most of Ari and Evo API, leaving some of the model-specific implementation for the `ozobot-evo` and `ozobot-ari` packages.

See the [monorepo](https://github.com/ozobot/python-libraries) for more details. 
